==> scala-k8s-objects_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/ContainerImage.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Describe a container image */
final case class ContainerImage(
  names : Option[Seq[String]] = None,
  sizeBytes : Option[Int] = None
) {

  /** Returns a new data with names set to new value */
  def withNames(value: Seq[String]) : ContainerImage = copy(names = Some(value))
  /** Appends new values to names */
  def addNames(newValues: String*) : ContainerImage = copy(names = Some(names.fold(newValues)(_ ++ newValues)))
  /** if names has a value, transforms to the result of function*/
  def mapNames(f: Seq[String] => Seq[String]) : ContainerImage = copy(names = names.map(f))

  /** Returns a new data with sizeBytes set to new value */
  def withSizeBytes(value: Int) : ContainerImage = copy(sizeBytes = Some(value))
  /** if sizeBytes has a value, transforms to the result of function*/
  def mapSizeBytes(f: Int => Int) : ContainerImage = copy(sizeBytes = sizeBytes.map(f))
}

object ContainerImage {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.ContainerImage, T] = new Encoder[io.k8s.api.core.v1.ContainerImage, T] {
        def apply(o: io.k8s.api.core.v1.ContainerImage) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("names", o.names)
            .write("sizeBytes", o.sizeBytes)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, ContainerImage] = new Decoder[T, ContainerImage] {
      def apply(t: T): Either[String, ContainerImage] = for {
          obj <- ObjectReader(t)
          names <- obj.readOpt[Seq[String]]("names")
          sizeBytes <- obj.readOpt[Int]("sizeBytes")
      } yield ContainerImage (
          names = names,
          sizeBytes = sizeBytes
        )
    }
}

==> scala-k8s-objects_2.12-0.18.0-sources.jar: io/k8s/api/core/v1/ContainerImage.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Describe a container image */
final case class ContainerImage(
  names : Option[Seq[String]] = None,
  sizeBytes : Option[Long] = None
) {

  /** Returns a new data with names set to new value */
  def withNames(value: Seq[String]) : ContainerImage = copy(names = Some(value))
  /** Appends new values to names */
  def addNames(newValues: String*) : ContainerImage = copy(names = Some(names.fold(newValues)(_ ++ newValues)))
  /** if names has a value, transforms to the result of function*/
  def mapNames(f: Seq[String] => Seq[String]) : ContainerImage = copy(names = names.map(f))

  /** Returns a new data with sizeBytes set to new value */
  def withSizeBytes(value: Long) : ContainerImage = copy(sizeBytes = Some(value))
  /** if sizeBytes has a value, transforms to the result of function*/
  def mapSizeBytes(f: Long => Long) : ContainerImage = copy(sizeBytes = sizeBytes.map(f))
}

object ContainerImage {

    implicit val encoder : Encoder[io.k8s.api.core.v1.ContainerImage] = new Encoder[io.k8s.api.core.v1.ContainerImage] {
        def apply[T : Builder](o: io.k8s.api.core.v1.ContainerImage) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("names", o.names)
            .write("sizeBytes", o.sizeBytes)
            .build
        }
    }

    implicit val decoder: Decoder[ContainerImage] = new Decoder[ContainerImage] {
      def apply[T : Reader](t: T): Either[String, ContainerImage] = for {
          obj <- ObjectReader(t)
          names <- obj.readOpt[Seq[String]]("names")
          sizeBytes <- obj.readOpt[Long]("sizeBytes")
      } yield ContainerImage (
          names = names,
          sizeBytes = sizeBytes
        )
    }
}
